==> HostCMS.Free_6.7.tar.gz: modules/shop/group/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Products groups',
	'links_groups' => "Group",
	'links_groups_add' => "Add",
	'name' => "<acronym title=\"Name of products group\">Group name</acronym>",
	'description' => "<acronym title=\"Products group description\">Group description</acronym>",
	'image_large' => "<acronym title=\"Image for products group\">Group image</acronym>",
	'image_small' => "<acronym title=\"Small image for products group\">Small group image</acronym>",
	'sorting' => "<acronym title=\"Groups sorting order\">Sorting order</acronym>",
	'indexing' => "<acronym title=\"Enable indexation of groups by on-site search module\">Index group</acronym>",
	'active' => "<acronym title=\"Activity status of online store group\">Active</acronym>",
	'path' => "<acronym title=\"Path, e.g. group_30312\">Path</acronym>",
	'seo_title' => '<acronym title="Meta element title">Title</acronym>',
	'seo_description' => '<acronym title="Meta element description">Description</acronym>',
	'seo_keywords' => '<acronym title="Meta element keywords">Keywords</acronym>',
	'guid' => '<acronym title="Product group identifier for CommerceML format, e.g. ID00006831">CommerceML product group identifier</acronym>',
	'siteuser_id' => 'Website user',
	'groups_add_form_title' => "Add products group information",
	'groups_edit_form_title' => "Edit products group information",
	'tab_yandex_market' => 'Export/Import',
	'tab_group_description' => 'Description',
	'tab_group_seo' => 'SEO',
	'parent_id' => '<acronym title="Group that group belongs to">Group</acronym>',
	'exec_typograph_for_description' => '<acronym title="Use prepress service to description">Use prepress service to description</acronym>',
	'use_trailing_punctuation_for_text' => '<acronym title="Optical text alignment function moves punctuation characters beyond the typing borders">Optical alignment</acronym>',
	'id' => "Id",
	'shop_id' => "Shop id",
	'edit_success' => "Products group added successfully!",
	'copy_success' => "Products group copied successfully!",
	'markDeleted_success' => "Products group deleted successfully!",
	'changeActive_success' => 'Status changed successfully!',
	'properties' => "Properties",
	'list_of_property_for_group' => "Properties list of product group",
	'tab_properties' => "Additional properties",
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'error_URL_shop_group' => 'Group already contains subgroup with the same URL!',
	'error_URL_isset_item' => 'Group already contains item with the same URL!',
	'apply_success' => "Information has been successfully changed",
	'move_success' => 'Product groups transferred successfully',
	'items_catalog_image' => "<acronym title=\"Group image\">Group image</acronym>",
	'items_catalog_image_small' => "<acronym title=\"Small group image\">Small group image</acronym>",
	'tab_seo_templates' => 'SEO templates',
	'seo_group_header' => 'Group templates',
	'seo_item_header' => 'Item templates',
	'seo_group_title_template' => 'TITLE template',
	'seo_group_description_template' => 'DESCRIPTION template',
	'seo_group_keywords_template' => 'KEYWORDS template',
	'seo_item_title_template' => 'TITLE template',
	'seo_item_description_template' => 'DESCRIPTION template',
	'seo_item_keywords_template' => 'KEYWORDS template',
	'markDeleted' => 'Delete group',
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/group/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2023 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Products groups',
	'links_groups' => "Group",
	'links_groups_add' => "Add",
	'name' => "Group name",
	'description' => "Group description",
	'image_large' => "Group image",
	'image_small' => "Small group image",
	'sorting' => 'Sort',
	'indexing' => "Index group",
	'active' => 'Active',
	'path' => "<acronym title=\"Path, e.g. group_30312\">Path</acronym>",
	'seo_title' => 'Title',
	'seo_description' => 'Description',
	'seo_keywords' => 'Keywords',
	'guid' => '<acronym title="Product group identifier for CommerceML format, e.g. ID00006831">CommerceML product group identifier</acronym>',
	'siteuser_id' => 'Client',
	'groups_add_form_title' => "Add products group information",
	'groups_edit_form_title' => "Edit products group information",
	'tab_yandex_market' => 'Export/Import',
	'tab_group_description' => 'Description',
	'tab_group_seo' => 'SEO',
	'parent_id' => 'Group',
	'exec_typograph_for_description' => 'Use prepress service to description',
	'use_trailing_punctuation_for_text' => '<acronym title="Optical text alignment function moves punctuation characters beyond the typing borders">Optical alignment</acronym>',
	'id' => "Id",
	'shop_id' => "Shop id",
	'edit_success' => "Products group added successfully!",
	'copy_success' => "Products group copied successfully!",
	'markDeleted_success' => "Products group deleted successfully!",
	'changeActive_success' => 'Status changed successfully!',
	'properties' => "Properties",
	'list_of_property_for_group' => "Properties list of product group",
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'error_URL_shop_group' => 'Group already contains subgroup with the same URL!',
	'error_URL_isset_item' => 'Group already contains item with the same URL!',
	'apply_success' => "Information has been successfully changed",
	'move_success' => 'Product groups transferred successfully',
	'items_catalog_image' => "Group image",
	'items_catalog_image_small' => "Small group image",
	'tab_seo_templates' => 'SEO templates',
	'seo_group_header' => 'Group templates',
	'seo_item_header' => 'Item templates',
	'seo_group_title_template' => 'TITLE template',
	'seo_group_description_template' => 'DESCRIPTION template',
	'seo_group_keywords_template' => 'KEYWORDS template',
	'seo_item_title_template' => 'TITLE template',
	'seo_item_description_template' => 'DESCRIPTION template',
	'seo_item_keywords_template' => 'KEYWORDS template',
	'markDeleted' => 'Delete group',
	'shortcut_success' => "Group shortcut added successfully",
	'change_attributes_success' => 'Attributes changed successfully!',
	'items_total_count' => 'Number of active items',
	'seo_group_h1_template' => 'H1 Template',
	'seo_item_h1_template' => 'H1 Template',
);
